import PropTypes from "prop-types";
import React, { Component } from "react";
import * as ScanditSDK from "scandit-sdk";

import Picker from "./picker-wrapper";

class Scanner extends Component {
  picker = new Picker();
  scannerContainerRef = React.createRef();

  componentDidMount = () => {
    this.configureLibrary().then(() => this.initializePicker());
  };

  componentWillUnmount = () => {
    if (this.picker) {
      this.picker.destroy();
    }
  };

  componentDidUpdate = (prevProps) => {
    this.updatePicker(prevProps);
  };

  configureLibrary = () => {
    return ScanditSDK.configure(this.props.licenseKey, {
      engineLocation: this.props.engineLocation,
      preloadBlurryRecognition: this.props.preloadBlurryRecognition,
      preloadEngine: this.props.preloadEngine,
    });
  };

  initializePicker = () => {
    this.picker.initialize(this.scannerContainerRef.current, this.props);
  };

  updatePicker = (prevProps) => {
    this.picker != null && this.picker.update(prevProps, this.props);
  };

  render() {
    return <div ref={this.scannerContainerRef} />;
  }
}

Scanner.propTypes = {
  licenseKey: PropTypes.string.isRequired,
  engineLocation: PropTypes.string.isRequired,
  preloadBlurryRecognition: PropTypes.bool,
  preloadEngine: PropTypes.bool,
  accessCamera: PropTypes.bool,
  camera: PropTypes.object,
  cameraSettings: PropTypes.object,
  cameraType: PropTypes.any,
  enableCameraSwitcher: PropTypes.bool,
  enablePinchToZoom: PropTypes.bool,
  enableTapToFocus: PropTypes.bool,
  enableTorchToggle: PropTypes.bool,
  guiStyle: PropTypes.any,
  laserArea: PropTypes.any,
  mirrorImage: PropTypes.bool,
  paused: PropTypes.bool,
  playSoundOnScan: PropTypes.bool,
  scanSettings: PropTypes.object,
  singleImageModeSettings: PropTypes.object,
  targetScanningFPS: PropTypes.number,
  vibrateOnScan: PropTypes.bool,
  videoFit: PropTypes.any,
  visible: PropTypes.bool,
  viewfinderArea: PropTypes.any,
  zoom: PropTypes.number,

  onReady: PropTypes.func,
  onScan: PropTypes.func,
  onScanError: PropTypes.func,
  onProcessFrame: PropTypes.func,
  onSubmitFrame: PropTypes.func,
};

export default Scanner;
